# geek_code

## Geek Code 5.x

# What Is Geek Code?
The Geek Code, developed in 1993, is a series of letters and symbols used by self-described "geeks" to inform fellow geeks about their personality, appearance, interests, skills, and opinions.

The geek code attempts a concise description of your being in 'geek space', spanning key dimensions using a small set of categories and quantifying them with qualifiers ( or qualifying them with quantifiers, as you wish).

The idea is that everything that makes a geek individual can be encoded in a compact format which only other geeks can read. This is deemed to be efficient in some sufficiently geeky manner.

Share your geek code with friends and acquaintances! Help them understand that "The geeks of today are the trendsetters of tomorrow."


Older Versions
------

Version 0.1 was created and written by Robert A. Hayden, a student (and later graduate) of Mankato State University. It consisted of only about five categories.

Version 0.2 was mostly a spelling and bug fix.

Version 0.3 added a couple more categories.

[Click here to see Version 0.3 on the web!](https://www.cs.cmu.edu/afs/cs/user/scotts/ftp/bulgarians/geek-code.html "This is perhaps the oldest still surviving example of Geek Code on the web!")

Version 1.0 was released about 4 months after 0.3 on July 17, 1993 and added several more categories as well as the rules for cross-overs and variables. 1.0.1 was a bug-fix released later that day.

[Click here to see Version 1.0.1 here!](http://www.textfiles.com/100/codegeek.txt)

Version 2.0 was released one year after version 1.0 on July 17, 1994. Version 2.0 and represents the recommendations of many dozens of people, and at least 75 additions were added in that version.

Version 2.1 was released one day later, and was mostly bugfixes to make Geek Code internally consistent with itself.

[Click here to see version 2.1 on the web!](http://www.aleph.se/Nada/nerdiness/geek2)

Version 3.x of Geek Code was released on March 5, 1996. It was a huge refinement over version 2.x! One of the main problems with 2.x was that it was too long, and much of its length was attributed to non-geek categories. One of the goals of 3.x is to eliminate many of the non-geeky and unimportant categories in order to make room for geeky traits. "More geek, less bullshit" was a good motto for this version. It removed some categories from 2.x that were just downright odd (like automobiles, nutrition, and **Barney**?)

[Version 3.1](https://web.archive.org/web/20090220181018/http://geekcode.com/geek.html)

[Version 3.1 Generator](https://www.joereiss.net/geek/geek.html)

[Version 3.1 Decoder](http://www.ebb.org/ungeek/ "Real geeks shouldn't need this though.")

Version 3.12 is the version used for the `geekcode` Linux package still available on Debian and Ubuntu. The Linux package only contains the basic version 3 Geek Code, and does not support crossovers and variables.

Version 4.x was released on GitHub on October 18, 2019. Some categories have been removed, others added, some altered. The v3.x undergraduate weltanschaung has been supplanted by a more seasoned outlook.

In version 4, tv/series are given its own category (since geeks may watch something else besides Star Trek)

[Click here to see Version 4.0!](https://github.com/telavivmakers/geek_code/blob/8903d925d6660d9afa661d6cb99f13976d95242f/README.md)

Version 4.5 was mostly bugfixes to make the current geek code internally consistent, and correct any older 3.x code that was lurking in the shadows.

Welcome to The Geek Code Version 5.0
======

The code no longer uses case-sensitive categories. To accomplish this, some categories and letters have been changed. Letter groupings are used so that there was no repetition of single letters among the categories.

Some categories were merged, and couple new symbols were added. The header of the GEEK CODE BLOCK (which used to mimic the output of a GPG BLOCK) now merges both header and version in a single line.

In version 5.x, each category is designed to help uniquely identify a geek with less parallelism existing among categories. There are no categories that refer backwards to previously defined categories.

And there's never a need to define "sex" in three different ways!

In our own way, this version also adheres to the motto "more geek, less crap". And this has really enhanced the "seasoned outlook" that v4.x adopted in its code.

How Does It Work?
------

The code consists of a set of alphanumeric identifiers indicating the various categories (and subcategories), and qualifiers + and – following the identifiers indicating amount/size/level of proficiency/etc. These qualifiers can be stacked, e.g H+++ indicates a person of extremely skilled with hardware (the H indicating Hardware).

The broad categories encoded are: Geek of, Wetware, Computers, Politics, Entertainment, Lifestyle. Most have subcategories and you can answer at any level of detail desired, thus eg. U++ indicates someone highly interested/proficient in Unix, while ULDU++ indicates someone into Unix/Linux/Debian/Ubuntu (each additional step is a derivative of the previous step). Multiple subcategories can be indicated with a forward slash, e.g GCS/GM indicates a Geek of Computer Science and Math.

Some categories will be irrelevant, so ignore them. Some of the qualifiers will not match with you exactly, so choose that qualifier that most closely matches you.

Given a set of category/qualifier strings for any of the above (skip anything you dont want to answer/not relevant/classified/unknown/indeterminate/etc).

It's time to assemble your code for displaying to the world. Take the substrings and concatenate with a space between. When completed, it will look something like the following:

```
GCS^/GM^ A++(a?) B_:--:+:-:+ C++(C-) D+:+ CM++(++++) MW11_(++) ULD++++$ MC-- Lbash+++/LC#+/Lj+/Lpy++/Lvb IO+++:---(+) G:exarobibliologist E++ H+ PGP PSG PE TDW+/TEX+++/THRO++++/TMON+++/TOB+++/TSTsnw+++/TSTld+++/TSTdsc-- RPG+++(*)>$ BK+++ KX+++ INTJ-A R-- Y+++
```

A GEEK CODE BLOCK parodies the output created by PGP, and attempts to universalize how you will see the Geek Code around the net. Line breaks can be added if needed (but 

```
-----BEGIN GEEK CODE BLOCK VERSION 5.1-----
GCS^/GM^ A++(a?) B_:--:+:-:+ C++(C-) D+:+ CM++(++++)
MW11_(++) ULD++++$ MC-- Lbash+++/LC#+/Lj+/Lpy++/Lvb
IO+++:---(+) PGP G:exarobibliologist E++ H+ PSG PE
TDW+/TEX+++/THRO++++/TMON+++/TOB+++/TSTsnw+++/TSTld+++/
TSTdsc-- RPG+++(*)>$ BK+++ KX+++ INTJ-A R-- he/him+++
-----END GEEK CODE BLOCK VERSION 5.1-----
```

Special characters
------

A few special characters allow for the (ultimately wrong but practically useful) notion that geeks can seldom be strictly quantified.

```
+	=	indicates an increased amount of geekiness in a particular area. Each additional + raises the level further.
```

```
_	=	(Optional) indicates a baseline answer. _ is one step above -, and one step below +. Therefore, _ is never combined with + or -
```

For example, instead of leaving it blank/empty, a geek of average shape and size could write d_:_ to indicate they are at the baseline.

```
-	=	indicates a decreased amount of geekiness in a particular area. Each additional - reduces the level further.
```

```
@	=	for this variable, said trait is not very rigid, may change with time or with individual interaction.
```

For example, Geeks who happen to very much enjoy Star Trek: Picard as a whole, but aren't sure how they like the current season might list themselves as TSTpic+++@.

```
()	=	for indicating "cross-overs" or ranges. Geeks who go from C+ to C— depending on the situation (i.e. mostly "C+") could use C+(—).
```

@ is different from () in that () has finite limits within the category, while @ ranges all over.

```
$	=	Indicates that this particular category is done for a living.
```

For example, UL+++$ indicates that the person utilizes Unix and gets paid for it. Quite a lucky geek, for sure.

```
^	=	Indicates that the geek has a degree or certificate in this area or field.
```

For example, GCS^/GMU/GTW^ indicates that this is a Geek of Computer Science (with a degree in this field), a Geek of Music, and a Geek of Technical Writing (with a certificate in this field)

```
>	=	for 'wannabe' ratings. Indicating that while the geek is currently at one rating, they are striving to reach another.
```

For example, UL+++>$ indicating a geek that is currently Linux savvy, but wants to someday make money at it.

```
?	=	Unless stated otherwise within the specific category, the ? is placed after the category identifier and indicates that the geek has no knowledge about that specific category.
```

```
!	=	Placed BEFORE the category. Unless stated otherwise, indicates that the person refuses to participate in this category. This is unlike the ? variable as the ? indicates lack of knowledge, while the ! indicates stubborn refusal to participate.
```

For example, !MC would be a person that just plain refuses to have anything to do with Macintosh, while MC? would be a person that doesn't even know what Macintosh is.

The categories
======

G = GEEK OF - training/degree/interest/job
======

To start a code, a geek must declare himself or herself to be a geek. To do this, we start the code with a "G" to denote "GEEK", followed by one or two letters to denote the geek's occupation or field of study. Multi-talented geeks with more than one vocational training should denote their myriad of talents with a slash between each vocation (example: GCS/MU/TW).

```
GAI	=	Geek of Artificial Intelligence
GBIO	=	Geek of Biomedical Engineering
GB 	= 	Geek of Business
GC 	= 	Geek of Classics
GCA 	=	Geek of Commercial Arts
GCM 	=	Geek of Computer Management
GCS	=	Geek of Computer Science
GCC 	=	Geek of Communications
GDS	=	Geek of Data Science
GDVO	=	Geek of DevOps
GE 	=	Geek of Engineering
GED 	=	Geek of Education
GFA 	=	Geek of Fine Arts
GFS	=	Geek of Forensic Science
GG 	=	Geek of Government
GH 	=	Geek of Humanities
GIT 	=	Geek of Information Technology
GJ 	=	Geek of Jurisprudence (Law)
GLS 	=	Geek of Library Science
GL 	=	Geek of Literature
GMC 	=	Geek of Mass Communications
GM 	=	Geek of Math
GMD 	=	Geek of Medicine
GMU 	=	Geek of Music
GPA 	=	Geek of Performing Arts
GP 	=	Geek of Philosophy
GS 	=	Geek of Science (Physics, Chemistry, Biology, etc.)
GSS 	=	Geek of Social Science (Psychology, Sociology, etc.)
GTW 	=	Geek of Technical Writing
GVDD	=	Geek of Video Game Design
GO 	=	Geek of Other. Some types of geeks deviate from the normal geek activities. This is encouraged as true geeks come from all walks of life.
GU 	=	Geek of 'Undecided'. This is a popular vocation with incoming freshmen.
G! 	=	Geek of no qualifications nor interests; likely, cannot exist
GAT 	=	Geek of All Trades. For those geeks that can do anything and everything. GAT usually precludes the use of other vocational descriptors.
```

WETWARE (A,B,C,D) (age/beard/clothing/dimensions)
======

They say you never get a second chance to make a first impression.

The Geek, of course, doesn't believe any of that crap; on the internet, no one knows you're a dog, according to ancient meme. In any case this section allows you to list something about what you look like, conceivably for dating purposes or such nonsense. Also it lets us start off with 'abcd' for age/beard/clothing/dimensions.

A = Age
------

The only way to become a true geek is through practice and experience. To this end, your age becomes an important part of your geekiness. Use the qualifiers below to show your age (in Terran years). Base 10, wise guys.
```
A++++	=	60 and up
A+++	=	50-59
A++	=	40-49
A+	=	30-39
A	=	25-29
A-	=	20-24
A--	=	15-19
A---	=	10-14
A----	=	9 and under (Geek in training?)
A?	=	immortal
!A	=	it's none of your business how old I am
A=	=	Share your exact age by placing a number after. For example: A=42
```

B = Beardliness/Hair
------

As facial hair plays some sort of role in geek space, serving as an expression of style, countercultural proclivities, etc. etc. and [unix beards](http://www.usenix.org.uk/content/unix_beards.html) being a thing we give it a category here despite its irrelevance to some fraction of the population.

The hair code is divided into 5 parts, delimited by a colon. The parts are (Head : Beard : Brows : Mustache : Sideburns)

```
+++	=	Some people look at me and think I'm Sasquatch I have so much hair
++	=	Amazing hair growth!
+	=	Some hair growth
	=	Average
-	=	Less than normal, partially shaved
--	=	Bald / Shaved
---	=	Alopecia / Unable to grow hair there
```

Thus B_:++:+:++:_ means that geek has an average head of hair, with an impressive beard, thick brows, an equally impressive mustachio, and ordinary sideburns.


C = Clothing
------

```
C++ 	=	I tend to wear conservative dress such as a business suit or worse, a tie.
C+ 	=	Good leisure-wear. Slacks, button-shirt, etc. No jeans, tennis shoes, or t-shirts.
C	=	I dress a lot like those found in catalog ads. Bland, boring, without life or meaning.
C- 	=	I'm usually in jeans and a t-shirt.
C--	=	My t-shirts go a step further and have a trendy political message on them.
C---	=	Punk dresser, including, but not limited to, torn jeans and shirts, body piercings, and prominent tattoos.
Cx	=	Cross Dresser
C?	=	I have no idea what I am wearing right now, let alone what I wore yesterday.
!C	=	No clothing. Quite a fashion statement, don't you think?
Cpu	=	I wear the same clothes all the time, no matter the occasion, forgetting to do laundry between wearings.
```

D = Dimensions
------

Geeks come in many shapes and sizes. Shape code is divided into two parts delimited by a colon, the first indicating vertical, and the second horizontal extent.
```
D+++:+++ 	=	I usually have to duck through doors/I take up three movie seats.
D++:++ 		=	I'm a basketball/linebacker candidate.
D+:+ 		=	I'm a little taller/rounder than most.
D: 		=	I'm an average geek
D-:-		=	I look up to most people. Everyone tells me to gain a few pounds.
D--:-- 		=	I look up to damn near everybody. I tend to have to fight against a strong breeze.
D---:--- 	=	I take a phone book with me when I go out so I can see to eat dinner. My bones are poking through my skin.
```

Example: D+++:--- indicates extremely tall and thin.


CM = COMPUTERS
======

There is a record of geeks that don't use computers. Unfortunately, they are all dead, having lived in an era of no computers.

All modern geeks have some exposure to computers. If you don't know what a computer is, you need to go back into your shell.

Most geeks identify themselves by their use of computers and computer networks. In order to quantify your geekiness level on computers, consult the following (consider the term 'computers' synonymous with 'computer network'). This category represents "general" computer aptitude. Categories below will get into specifics.

```
CM++++ 		=	I'll be first in line to get the new cybernetic interface installed into my skull.
CM+++		=	You mean there is life outside of Internet? I haven't logged out in weeks. I answer questions on StackOverflow.
CM++ 		=	Computers are a large part of my existence. I code in at least one language. I have StackOverflow bookmarked so I can find answers to my programming questions.
CM+ 		=	Computers are fun and I enjoy using them. I also know that when it says 'press any key to continue', I don't have to look for a key labeled 'ANY'.
CM		=	Computers are a tool, nothing more. I use it when it serves my purpose.
CM- 		=	Anything more complicated than my calculator and I'm screwed.
CM-- 		=	Where's the on switch?
CM--- 		=	Computer? Not interested. That's those machines with demons in them, right?
```

MW = Microsoft Windows
------

A good many geeks suffer through the use of various versions of Microsoft Windows.

Rate your Windows geekiness, and if desired you can include the versions of Windows you have used or are currently using.

For example: MW11+++ means that you are very proficient with Windows 11.

```
MW++++	=	I am a MS Windows programming god. I have designed/compiled 1+ .exe, .msi, or .dll
MW+++	=	I write/compile Microsoft code.
MW++	=	I have 'hacked' my Windows REGEDIT to unlock or fix various bugs on my machine.
MW+	=	I have installed my own custom sounds, wallpaper, and screen savers so my PC walks and talks like a fun house. I have a hundred fonts that I've installed but never used.
MW	=	I only use Windows for one specific purpose (like running Steam games), but I don't have to like it.
MW-	=	I'm still trying to install MS Windows and have at least one peripheral that never works right
MW--	=	MS Windows is a joke operating system. No one can find the error codes anymore, and even if they could no one can read hexadecimal to understand them!
MW---	=	Windows has set back the computing industry by at least 10 years. Bill Gates should be drawn, quartered, hung, shot, poisoned, disembowelled, and then REALLY hurt.
```

U = Unix
------

It seems that a Unix-based operating system is the OS of choice among most geeks. In addition to telling us about your Unix abilities, you can also show which specific Unix OS you are using. To accomplish this, you include a letter showing the brand with your rating. For example: UL++++ would indicate a sysadmin running Linux.

	U = Unix
		UL = Linux
			ULA = Arch
				ULAP = Pacman
			ULD = Debian
				ULDU = ubuntu
					ULDUM = Linux Mint
					ULDU* = 3rd party/discontinued ubuntu
				ULDD = Deepin
			ULF = Fedora
			ULRH = Red Hat Enterprise Linux
				ULRC = Centos
				ULRO = OpenSUSE
			ULG = Gentoo
				ULGC = ChromeOS / ChromiumOS
			ULS = Slackware
			UL* = other
		US = Sun OS/Solaris
		UA = AIX
		UH = HPUX
		UI = IRIX
		UC = SCO Unix
	U* = Some other one not listed
some examples
```
U++++	=	I am the sysadmin. If you try and crack my machine don't be surprised if the municipal works department gets an "accidental" computer-generated order to put start a new landfill on your front lawn or your quota is reduced to 4K.
U+++	=	I don't need to crack /etc/passwd because I just modified su so that it doesn't prompt me. The admin staff doesn't know I'm here.
U++	=	I've get the entire admin ticked off at me because I am always using all of the CPU time and trying to run programs that I don't have access to.
U+	=	I enjoy shell scripting and understand the fundamental importance of the difference between ' and `
U	=	I have a Unix account to do my stuff in
U-	=	I have a VMS account.
U--	=	I've seen Unix and didn't like it. DEC rules!
U---	=	Unix geeks are actually nerds in disguise.
```

MC = Mac/Apple
------

Many geeks have jumped the PC ship and moved over to using Apple products. Give notification of your Mac rating.

```
MC++	=	I am a Mac guru. Anything those DOS putzes and Unix nerds can do, I can do better, and if not, I'll write the damn software to do it.
MC+	=	A Mac has it's uses and I use it quite often.
MC 	=	I use a Mac, but I'm pretty indifferent about it.
MC- 	=	Macs suck. All real geeks have a character prompt.
MC-- 	= 	Macs do more than suck. They make a user stupid by allowing them to use the system without knowing what they are doing. Mac weenies have lower IQs than the fuzz in my navel.
```

L = Programming Languages
------

List a series of languages and your facility/opinion thereupon, for example Lpy++/LR+ would indicate high proficiency in python and above average knowledge of R.

```
Lasm 		=	Assembly
Lbash		=	Bourne Again Shell
LC		=	C programming lang
LCpp		=	C plus plus
LC#		=	C sharp
Lgo 		=	Go
Lj		=	Java
Ljs		=	Javascript
Llll		=	Low-level Lisp
Llua		=	Lua
LM 		=	MATLAB
LoC 		=	Objective C
LP 		=	Perl
Lphp		=	PHP
Lpy		=	Python
LQ#		=	Q sharp
LR 		=	R
LRu 		=	Ruby
Lsql 		=	SQL
Lvb		=	Visual Basic
Lwps		=	Windows PowerShell
````
For example:
```
Lpy+++		=	I am Guido
Lpy++		=	I maintain/contribute to the python code base
Lpy+		=	I am a pythonista – love python and use it all the time , consider whether things I say are 'pythonic'
Lpy		=	I am neutral on python , its ok for some things.
Lpy-		=	Python is for hobbies
Lpy-- 		=	I do not like python, it is an ugly aberration for people incapable of grasping the subtle power of [C|Lisp|assembly]
```

IO = Input/Output
------

How do you take your data? How do you present your data to others? Input/Output is a single entry with two sections delimited by a colon describing how user-friendly or not you are.

```
Input Side
IO+++	=	I wrote my own database system as current performance limitations were irking me
IO++	=
IO+	=
IO	=
IO-	=
IO--	=
IO---	=	Keep the dirty stuff under the hood, building a cool GUI is where its at

Output Side
IO+++	=	I am a java bean
IO++	=
IO+	=
IO	=
IO-	=
IO--	=	My user interface is a text-only Terminal. Don't even touch the mouse
IO---	=	I couldnt care less about the 'user experience'; users can be approximated using Bayesian techniques
```

For example: IO+++:--- likely means you send and recieve data in as raw a form as possible.


PGP
------

Pretty Good Privacy (aka PGP) is a program available on many platforms that will encrypt files so that prying eyes (particularly governmental) can't look at them.
```
PGP++++		=	I am Philip Zimmerman
PGP+++		=	I don't send or answer mail that is not encrypted, or at the very least signed. If you are reading this without decrypting it first, something is wrong. IT DIDN'T COME FROM ME!
PGP++ 		=	I have the most recent version and use it regularly
PGP+ 		=	"Finger me for my public key"
PGP 		=	I've used it, but stopped long ago.
PGP- 		=	I don't have anything to hide.
PGP-- 		=	I feel that the glory of the Internet is in the anarchic, trusting environment that so nurtures the exchange of information. Encryption just bogs that down.
PGP--- 		=	If you support encryption on the Internet, you must be a drug dealer or terrorist or something like that.
PGP---- 	=	Oh, here is something you all can use that is better (insert Clipper here).
```

G = GitHub Username
------

Good Version Control systems are a priority for most geeks coders. List which version control system you use, and your username so we can find you.
```
G	=	GitHub
Gb	=	BitBucket
Gbk	=	Bitkeeper
Gbn	=	Beanstalk
Gsvn	=	Subversion
Gtfs	= 	Team Foundation Server
```

Write your username, after the code, like the following examples:

```
G:exarobibliologist
Gbn:rutman
```

E = Electronics
------

```
E+++	=	I am lady ada
E++	=	I have fixed broken toasters without removing the plug, such is my skill and need for speed. 
E+	=	I know CMOS from BJT and why a comparator is not quite equivalent to an op amp
E	=
E-	=
E--	=	Electrons are interesting as theoretical constructs
```

H = Hardware
------

```
H+++	=	I smithed my own chainmail from iron I smelted with ore mined by means of steam-powered equipment I created from old car parts.
H++	=
H+	=
H	=
H-	=	I have used hammers metaphorically far more often than literally
H--	=	I prefer to take my laptop to the shop when the hardware acts up
```


POLITICS
======

The last few years has seen the rise of the political geek. This phenomena is little understood, but some theorize that it has come about because of the popular media's attempts to demonize the Internet and computer use in general, and the government's willingness to go along with it. Others propose that the aging geek population has simply started taking an interest in the world around them. Some support the "Sun Spot" theory. As of v4 some new subcategories are added to the PS and PE categories.


Politics and Social Issues
------

Where, in general, your political views on different social issues fall. The + and – ratings here roughly indicate left/right on the political spectrum.

Subcategories (give yourself a geek point if your first thought was 'actually, subsubcategories')

	PSG = green politics/sustainability/climate
	PSL = civil liberties
	PSS = gender politics

```
PS+++	=	Legalize drugs! Abolish the government. "Fuck the draft!"
PS++	=	I give to liberal causes. I march for gay rights. I'm a card carrying member of the ACLU. Keep abortion safe and legal.
PS+	=	My whole concept of liberalism is that nobody has the right to tell anybody else what to do, on either side of the political fence. If you don't like it, turn the bloody channel.
PS	=	I really don't have an opinion; nobody's messing with my freedoms right now.
PS-	=	Label records! Keep dirty stuff off the TV and the Internet.
PS--	=	Oppose sex education, abortion rights, gay rights. Rush Limbaugh is my spokesman.
PS---	=	Repent left-wing sinners and change your wicked evil ways. Buchanan/Robertson in '96.
```

Politics and Economic Issues
------

Note this category has been reversed as of v4 to maintain the loose left+ and right- association from the PS category.

```
PE+++	=	Capitalism is evil! Government should provide the services we really need. Nobody should be rich.
PE++	=	Keep the government off the backs of businesses. Deregulate as much as possible.
PE	=	Distrust both government and business.
PE-	=	It's ok to increase government spending, so we can help more poor people. Tax the rich! Cut the defense budget!
PE--	=	Balance the budget with spending cuts and an amendment.
PE---	=	Abolish antitrust legislation. Raise taxes on everyone but the rich so that the money can trickle-down to the masses.
```

ENTERTAINMENT
======

Geeks love to play. No matter their age, all geeks enjoy playing. Of course, the object of this entertainment takes a myriad of different forms. What is it that pushes a geek to play? Is it simply a desire to relive their childhood? Or perhaps there is a piece of geeky genetic code that requires intellectual stimulation. Who knows, maybe it's a Freudian thing…

T = TV
------

List what you think of the series you geek out to

```
TBBT		=	The Big Bang Theory
TB5		=	Babylon5
TDW		=	Doctor Who
TEX		=	The Expanse
TFF 		=	Firefly
TGT		=	Game of Thrones
THRO		=	Heroes
TI		=	'In search of…' with Leonard Nimoy
TLV		=	Leverage
	TLVr	=	Leverage: Redemption
Tmon		=	Monty Python (series/films)
TMM		=	Mad Max
TLOTR		=	Lord of the Rings
TL		=	Lost
TOB		=	Orphan Black
TRM 		=	rick&MORTY
TSG		=	Stargate
	TSG1	=	Stargate SG-1
	TSGa	=	Stargate Atlantis
	TSGu	=	Stargate Universe
	TSGoc	=	Stargate Origins Catherine
TST		=	Star Trek
	TSTanm	=	Star Trek - Animated Series
	TSTng	=	Star Trek - The Next Generation
	TSTds9	=	Star Trek - Deep Space Nine
	TSTv	=	Star Trek - Voyager
	TSTe	=	Star Trek - Enterprise
	TSTdsc	=	Star Trek - Discovery
	TSTpic	=	Star Trek - Picard
	TSTld	=	Star Trek - Lower Decks
	TSTst	=	Star Trek - Short Treks
	TSTpro	=	Star Trek - Prodigy
	TSTsnw	=	Star Trek - Strange New Worlds
TSW		=	Star Wars
	TSWcw	=	Star Wars Clone Wars
	TSWman	=	The Mandalorian
	TSWand	=	Star Wars - Andor
	TSWobi	=	Star Wars - Obi-Wan Kenobi
	TSWbob	=	Star Wars - Book of Boba Fett
	TSWv	=	Star Wars - Visions
	TSWbb	=	Star Wars - The Bad Batch
	TSWres	=	Star Wars - Resistance
	TSWreb	=	Star Wars - Rebels
TW13	=	Warehouse 13

````
Example Star Trek info
```
TST+++	=	It's not just a TV show, it's a religion. I know all about warp field dynamics and the principles behind the transporter. I have memorized the TECH manual. I speak Klingon. I go to cons with Vulcan ears on. I have no life.
TST++	=	It's the best show around. I have all the episodes and the movies on tape and can quote entire scenes verbatim. I've built a few of the model kits too. But you'll never catch me at one of those conventions. Those people are kooks.
TST+	=	It's a damn fine TV show and is one of the only things good on television any more.
TST	=	It's just another TV show
TST-	=	Maybe it is just me, but I have no idea what the big deal with Star Trek is. Perhaps I'm missing something but I just think it is bad drama.
TST--	=	Star Trek is just another Space Opera. William Shatner isn't an actor, he's a poser! And what's with this Jean-Luc Picard? A Frenchman with a British accent? Come on. Isn't Voyager just a rehash of Lost in Space? Has Sisko even breathed in the last two seasons? Come on. I'd only watch this show if my remote control broke.
TST---	=	Star Trek SUCKS! It is the worst crap I have ever seen! Hey, all you trekkies out there, GET A LIFE! (William Shatner is a t—)
````

RPG = Roleplaying
------

Role-playing games such as Dungeons & Dragons have long been a part of the traditional geek life. Because geeks often become so involved in their role-playing that they lose touch with reality, include one of the following role-playing codes.
```
RPG+++	=	I've written and published my own gaming materials.
RPG++	=	There is no life outside the role of the die. I know all of piddly rules of (chosen game). _MY_ own warped rules scare the rest of the players.
RPG+	=	I've got my weekly sessions set up and a character that I know better than I know myself.
RPG	=	Role-Playing? That's just something to do to kill a Saturday afternoon
RPG-	=	Gosh, what an utter waste of time!
RPG--	=	Role-Players are instruments of pure evil.
RPG---	=	I work for T$R.
RPG*	=	I thought life WAS role-playing?
```

BK = Books
------

In addition (or maybe on the other hand), many geeks have lives that revolve around books.

```
BK++++	=	I read a book a day. I have library cards in three states. I have discount cards from every major bookstore. I've ordered books from another country to get my Favorite Author Fix.
BK+++	=	I consume a few books a week as part of a staple diet.
BK++	=	I find the time to get through at least one new book a month.
BK+	=	I enjoy reading, but don't get the time very often.
BK	=	I read the newspaper and the occasional book.
BK-	=	I read when there is no other way to get the information.
BK--	=	I take in knowledge by osmosis
BK---	=	I did not actually READ the geek code, I just had someone tell me.
```

K = Comics
------

Subcategories
```
	KD	=	Dilbert
	KX	=	XKCD
	KM	=	Manga
	KM!	=	Hentai
```

LIFESTYLE
======

Geeks, unlike the lower lifeforms known as nerds, have lives. They have things to do that are in the outside world. Of course, this is usually done with other geeks, but that's not the point. The point is,, that geeks are not necessarily the outcasts society often believes they are. The fact is that society isn't kool enough to be included in our activities.

MBTI / PERSONALITY
------

Most geeks have at one time or other taken a Myers & Briggs Type Indicator test. If you want to, include your letters in the code here.


R = Residence
------

Tell us about your geeky home.

```
R+++	=	Living in a cave with 47 computers and an Internet feed, located near a Dominoes pizza. See !d.
R++	=	Living alone, get out once a week to buy food, no more than once a month to do laundry. All surfaces covered.
R+	=	Friends come over to visit every once in a while to talk about Geek things. There is a place for them to sit.
R	=	Living with one or more registered Geeks.
R-	=	Living with one or more people who know nothing about being a Geek and refuse to watch geeky shows on TV.
R--	=	Married (or living romantically with someone.)
R---	=	Married with children – Al Bundy can sympathize

R! I am stuck living with my parents!
R* I'm not sure where I live anymore. This lab/workplace seems like home to me.
```

RELATIONSHIPS, SEX, AND GENDER
======

While many geeks are highly successful at having relationships, a good many more are not.

Geeks have traditionally had problems with sex (ie, they never have any). Because geeks are so wrapped up in their sexuality (or lack of sexuality), it is important that the geek be willing to quantify their sexual experiences.

This code also is used to denote the gender of the geek.

Share your pronouns followed by the modifier to show how succesful you have been with relationships and sex.

Pronouns should always be lowercase to prevent them from being mistaken for current or future geekcode (which is capitalized in most cases).

```
*	=	I'm a pervert
**	=	I've been known to make perverts look like angels.
++++	=	I've got a few rugrats to prove I've been there.
+++	=	Married, so I can get it (theoretically) whenever I want.
++	=	I was once referred to as 'easy'. I have no idea where that might have come from though.
+	=	I've had sex
_	=	I've had sex. Oh! You mean with someone else? Then no.
-	=	Not having sex by choice.
--	=	People just aren't interested in dating me...
---	=	Not having sex because I'm a nun or a priest.
%	=	signifying membership in the SBCA (Sour Bachelor(ette)'s Club of America). The motto is 'Bitter, but not Desperate'.
!	=	None of your business what my sex life is like!
>+	=	Desperate for experience
```

For example:

he/him+++

(Deprecated / Optional)
Females may use 'X' in this category. Males may use 'Y'. Other genders may use 'Q'. Those that do not wish to disclose their gender can use 'Z'.